@@ -86,7 +86,7 @@ static void debugStatement(void)
 		return;
 	if (sql_debug)
 		appendFileNF(sql_debuglog, stmt_text);
-	if (sql_debug2)
+	if (sql_debug)
 		puts(stmt_text);
 }				/* debugStatement */
 
@@ -795,7 +795,7 @@ sql_blobInsert(const char *tabname, const char *colname, int rowid,
 
 	if (sql_debug)
 		appendFile(sql_debuglog, "%d rows affected", rv_lastNrows);
-	if (sql_debug2)
+	if (sql_debug)
 		printf("%ld rows affected\n", rv_lastNrows);
 	SQLFreeHandle(SQL_HANDLE_STMT, hstmt);
 	exclist = 0;
@@ -1214,11 +1214,12 @@ Count(*) becomes decimal(15,0).  So be careful.
 #endif
 		}
 
+#if 0
 		if (current_driver == DRIVER_SQLITE) {
-/* Every column looks like a text blob, but it is really a string. */
-			coltype = SQL_CHAR;
-			colprec = STRINGLEN;
+// at some point we had to turn text blob into string.
+// Guess we don't need to do that any more.
 		}
+#endif
 
 		rv_nullable[i] = (nullable != SQL_NO_NULLS);
 
@@ -1343,7 +1344,7 @@ static bool execInternal(const char *stmt, int mode)
 			if (sql_debug)
 				appendFile(sql_debuglog, "%d rows affected",
 					   rv_lastNrows);
-			if (sql_debug2)
+			if (sql_debug)
 				printf("%ld rows affected\n", rv_lastNrows);
 		}
 	}
@@ -1477,7 +1478,7 @@ static int prepareCursor(const char *stmt, bool scrollflag)
 	hstmt = o->hstmt;
 	if (sql_debug)
 		appendFile(sql_debuglog, "new cursor %d", o->cid);
-	if (sql_debug2)
+	if (sql_debug)
 		printf("new cursor %d\n", o->cid);
 	rc = SQLSetStmtOption(hstmt, SQL_CURSOR_TYPE,
 			      scrollflag ? SQL_CURSOR_STATIC :
