@@ -338,6 +338,7 @@ extern char *dbarea, *dblogin, *dbpw;	/* to log into the database */
 extern bool fetchBlobColumns, ls_reverse;
 extern uchar ls_sort, dirWrite;
 extern char lsformat[12];
+extern bool dno; // directory names only
 extern bool caseInsensitive, searchStringsAll, searchWrap, ebre;
 extern bool allowRedirection;	/* from http code 301, or http refresh */
 extern bool sendReferrer;	/* in the http header */
@@ -491,7 +492,8 @@ int ehsn;
 	bool browseMode:1;	/* browsing html */
 	bool changeMode:1;	/* something has changed in this file */
 	bool quitMode:1;	/* you can quit this buffer any time */
-	bool dirMode:1;		/* directory mode */
+	bool dirMode:1;		// directory mode
+	bool dnoMode:1;		// directory names only
 	bool undoable:1;	/* undo is possible */
 	bool sqlMode:1;		// accessing a table
 	struct DBTABLE *table;	/* if in sqlMode */
@@ -558,8 +560,8 @@ struct htmlTag {
 	int seqno; // tag sequence number in this window
 	int gsn; // global sequence number, for rooting
 	char *js_file;
-	int js_ln;			/* line number of javascript */
-	int lic;		/* list item count, highly overloaded */
+	int js_ln;			// line number of javascript
+	int lic;		// list item count, highly overloaded
 	int slic; /* start list item count */
 	int action;
 	const struct tagInfo *info;
