@@ -135,6 +135,7 @@ void delTimers(const Frame *f);
 void runTimer(void);
 void showTimers(void);
 void domOpensWindow(const char *href, const char *name);
+int tableType(const Tag *t);
 char *render(void);
 bool itext(int d);
 struct htmlTag *line2tr(int ln);
@@ -158,6 +159,7 @@ void htmlInputHelper(Tag *t);
 void prerender(void);
 const char *fakePropName(void);
 void decorate(void);
+void rowspan(void);
 
 // sourcefile=http.c
 void eb_curl_global_init(void);
@@ -289,7 +291,7 @@ bool memoryOutToFile(const char *filename, const char *data, int len, int msgcre
 void truncate0(const char *filename, int fh);
 void caseShift(char *s, char action) ;
 void camelCase(char *s);
-char fileTypeByName(const char *name, bool showlink) ;
+char fileTypeByName(const char *name, int showlink) ;
 char fileTypeByHandle(int fd) ;
 off_t fileSizeByName(const char *name) ;
 off_t fileSizeByHandle(int fd) ;
