@@ -216,9 +216,10 @@ put1:
 }
 
 // For <h3><div>hello</div></h3> which should not happen, but does
+// And for <blockquote><p> which is prefectly fine
 static void h3div(char *buf)
 {
-	char *s;
+	char *s, *t;
 	bool in_h = false;
 	for(s = buf; *s; ++s) {
 		if(*s == '\f' && s[1] == 'h' &&
@@ -230,6 +231,20 @@ static void h3div(char *buf)
 			if(in_h) *s = ' ';
 		} else in_h = false;
 	}
+	in_h = false;
+	for(s = t = buf; *s; ++s) {
+		if(*s == '\f' && s[1] == '`' && s[2] == '`'
+		&& isspaceByte(s[3])) {
+			memcpy(t, s, 3);
+			in_h = true, s += 3, t += 3;
+			continue;
+		}
+		if(isspaceByte(*s)) {
+			if(in_h) continue;
+		} else in_h = false;
+		*t++ = *s;
+	}
+	*t = 0;
 }
 
 /*********************************************************************
@@ -287,20 +302,33 @@ static void anchorSwap(char *buf)
 				continue;
 			}
 
-/* end of white space, should we swap it with prior tag? */
+// end of white space, should we swap it with prior tag?
 			if (w && a) {
-				memmove(a, w, s - w);
-				memmove(a + (s - w), tag, n);
-				change = true;
-				w = NULL;
+				const Tag *t = tagList[tagno];
+				const char *q;
+// don't move td past newline; it screws things up.
+				if(t->action != TAGACT_TD) {
+tagforward:
+					memmove(a, w, s - w);
+					memmove(a + (s - w), tag, n);
+					change = true;
+					w = NULL;
+					goto afterforward;
+				}
+// It's ok to move things around, unless it's a data table.
+				if(tableType(t) != 1) goto tagforward;
+				for(q = w; q < s; ++q)
+					if(*q != ' ') goto afterforward;
+				goto tagforward;
 			}
+afterforward:
 
-/* prior anchor has no significance */
+// prior anchor has no significance
 			a = NULL;
 
 			if (c != InternalCodeChar)
 				goto normalChar;
-/* some conditions that should never happen */
+// some conditions that should never happen
 			if (!isdigitByte(s[1]))
 				goto normalChar;
 			tagno = strtol(s + 1, &ss, 10);
@@ -338,7 +366,6 @@ static void anchorSwap(char *buf)
 normalChar:
 			w = 0;	/* no more whitespace */
 		}
-/* end of loop making changes */
 	}
 	debugPrint(4, "anchorSwap %d", cnt);
 }
@@ -414,26 +441,29 @@ putc:
 // Now compress the implied linebreaks into one.
 static void html_ws(char *buf)
 {
-	char c, d, *s, *w, *a;
+	char c, d, *s, *w, *w2, *a;
 	int n;
 	bool premode = false, pretag, strong, slash;
 	char *ss = 0;
 
 	for (s = buf; (c = *s); ++s) {
+
+// look for <pre>
 		if (c == InternalCodeChar && isdigitByte(s[1])) {
 			n = strtol(s + 1, &s, 10);
 			if (*s == '*') {
 				preFormatCheck(n, &pretag, &slash);
-				if (pretag)
-					premode = !slash;
+				if (pretag) premode = !slash;
 			}
 		}
-		if (!isspaceByte(c))
-			continue;
+
+		if (!isspaceByte(c)) continue;
 
 // whitespace region starts here.
-// Look for pipes inside whitespace, these are usually cell delimiters.
+// strong is anything harder than space, like <br> or <p> or <div>
 		strong = false;
+// watch for pipes inside whitespace, these are usually cell delimiters.
+// pipe ends a whitespace region if only spaces come before
 		for (w = s; isspaceByte(*w) || *w == '|'; ++w) {
 			if(*w == '|') {
 				if(strong) continue;
@@ -441,11 +471,20 @@ static void html_ws(char *buf)
 			}
 			if(*w != ' ') strong = true;
 		}
+
+// whitespace region from s up to w
 // pipes have to be internal to whitespace to be moved;
 // pipes at the end are left alone.
-		if(*w && *w != InternalCodeChar)
+// Look ahead past anchors
+		w2 = w;
+		while(*w2 == InternalCodeChar) {
+			n = strtol(w2 + 1, &w2, 10);
+			++w2;
+		}
+		if(*w2)
 			while(w[-1] == '|') --w;
-// move pipes to the front
+
+// move internal pipes to the front
 		for(ss = --w; w >= s; --w)
 			if(*w != '|') *ss-- = *w;
 		while(ss >= s) *ss-- = '|';
@@ -894,13 +933,21 @@ char *htmlReformat(char *buf)
 	char *new;
 	int l, tagno, extra;
 	char *fmark;		/* mark the start of a frame */
+	const int debugPhases = 0;
 
+	if(debugPhases) printf("rendered<%s>\n", buf);
 	cellDelimiters(buf);
+	if(debugPhases) printf("cells<%s>\n", buf);
 	html_tr(buf);
+	if(debugPhases) printf("translate<%s>\n", buf);
 	h3div(buf);
+	if(debugPhases) printf("h3div<%s>\n", buf);
 	anchorSwap(buf);
+	if(debugPhases) printf("swap<%s>\n", buf);
 	anchorUnframe(buf);
+	if(debugPhases) printf("unframe<%s>\n", buf);
 	html_ws(buf);
+	if(debugPhases) printf("whitespace<%s>\n", buf);
 
 	longcut = lperiod = lcomma = lright = lany = 0;
 	colno = 1;
